import * as React from 'react';
import { useState, useEffect, useRef } from 'react';
import { VimWasm } from 'vim-wasm';
export function useVim({ worker, drawer, debug, perf, onVimExit, onVimInit, onFileExport, readClipboard, onWriteClipboard, onError, onVimCreated, }) {
    const canvas = useRef(null);
    const input = useRef(null);
    const [vim, setVim] = useState(null);
    useEffect(() => {
        // componentDidMount
        const opts = drawer !== undefined
            ? {
                workerScriptPath: worker,
                screen: drawer,
            }
            : {
                workerScriptPath: worker,
                canvas: canvas.current,
                input: input.current,
            };
        const vim = new VimWasm(opts);
        vim.onVimInit = onVimInit;
        vim.onVimExit = onVimExit;
        vim.onFileExport = onFileExport;
        vim.readClipboard = readClipboard;
        vim.onWriteClipboard = onWriteClipboard;
        vim.onError = onError;
        if (canvas.current !== null) {
            canvas.current.addEventListener('dragover', (e) => {
                e.stopPropagation();
                e.preventDefault();
                if (e.dataTransfer) {
                    e.dataTransfer.dropEffect = 'copy';
                }
            }, false);
            canvas.current.addEventListener('drop', (e) => {
                e.stopPropagation();
                e.preventDefault();
                if (e.dataTransfer) {
                    vim.dropFiles(e.dataTransfer.files).catch(onError);
                }
            }, false);
        }
        if (onVimCreated !== undefined) {
            onVimCreated(vim);
        }
        vim.start({ debug, perf });
        setVim(vim);
        return () => {
            // componentWillUnmount
            if (vim.isRunning()) {
                vim.cmdline('qall!');
            }
        };
    }, []);
    if (drawer !== undefined) {
        return [null, null, vim];
    }
    return [canvas, input, vim];
}
const INPUT_STYLE = {
    width: '1px',
    color: 'transparent',
    backgroundColor: 'transparent',
    padding: '0px',
    border: '0px',
    outline: 'none',
    position: 'relative',
    top: '0px',
    left: '0px',
};
export const Vim = props => {
    const [canvasRef, inputRef] = useVim(props);
    if (canvasRef === null || inputRef === null) {
        // This component has no responsibility to render screen and handle inputs.
        return React.createElement(React.Fragment, null);
    }
    return (React.createElement(React.Fragment, null,
        React.createElement("canvas", { ref: canvasRef, style: props.style, className: props.className }),
        React.createElement("input", { ref: inputRef, style: INPUT_STYLE, autoComplete: "off", autoFocus: true })));
};
//# sourceMappingURL=index.js.map